@@ -1,4 +1,4 @@
-# $Id: Directory.pm 41443 2014-04-30 09:39:57Z anton $
+# $Id: Directory.pm 41695 2014-06-11 08:52:21Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/Directory.pm $
 
 use strict;
@@ -176,11 +176,8 @@ sub ldap_connection {
 		my $server = $cfhash->{'ldaphost'} || $self->server;
 		my $capath = $cfhash->{'capath'} || $self->capath || '/etc/ssl/certs/';
 		my $retries = $cfhash->{'ldapRetries'} || $self->retries || 1;
-
-		# N.B. Als gevolg van deze contructie moet ldap_connection altijd VOOR $self->ldapbase uit te lezen
 		my $ldapbase = $cfhash->{'ldapbase'} || $self->{ldapbase};
 		$self->ldapbase($ldapbase);
-		warn "ldapBASE: " . $self->ldapbase;
 
 		my $ssl = $self->ssl || 'on';
 		my $state;
@@ -339,6 +336,7 @@ sub getLdapEntriesByFilter {
 	my $base = $self->ldapbase;
 
 	warn "getLdapEntriesByFilter; filter: $filter" if $self->debug;
+	# LET OP, retourneert een REFerence naar lijst met entries
 	my $entries =  $self->searchLdap(base => $base, filter => $filter, attrs => $attrs);
 }
 
